{$ ctrl.image.properties.description $}

- Status {$ ::ctrl.image.status $}
- Filename {$ ::ctrl.image.properties.filename $}
- Type {$ ctrl.image | imageType $}

### Image

Size
  {$ ctrl.image.size | bytes $}
Min. Disk
  {$ ctrl.image.min_disk | gb $}
Min. RAM
  {$ ctrl.image.min_ram | mb $}
Disk Format
  {$ ctrl.image.disk_format | uppercase $}
Container Format
  {$ ctrl.image.container_format | uppercase $}

### {$ 'Security' | translate $}

Visibility
  {$ ctrl.image | imageVisibility $}
Protected
  {$ ::ctrl.image.protected | yesno $}
Checksum
  {$ ::ctrl.image.checksum $}

### Record Properties

Created
  {$ ctrl.image.created_at | date:'short' $}
Updated
  {$ ctrl.image.updated_at | date:'short' $}
ID
  {$ ctrl.image.id $}

### Custom Properties

{$ ctrl.resourceType.label(prop.name) $}
  {$ ctrl.resourceType.format(prop.name, prop.value) $}